hstrat.hstrat.stratum\_retention\_predicates
============================================

.. automodule:: hstrat.hstrat.stratum_retention_predicates

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicateDepthProportionalResolution
   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicateFixedResolution
   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicateNominalResolution
   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicatePerfectResolution
   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicateRecencyProportionalResolution
   hstrat.hstrat.stratum_retention_predicates.StratumRetentionPredicateStochastic

